pub struct AccessPolicyV2 {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub name: Box<FHIRString>,
pub description: Option<Box<FHIRString>>,
pub engine: Box<AccessPolicyv2Engine>,
pub attribute: Option<Vec<AccessPolicyV2Attribute>>,
pub rule: Option<Vec<AccessPolicyV2Rule>>,
pub target: Option<Vec<AccessPolicyV2Target>>,
}Expand description
A set of rules that govern how a system resource is accessed and used.
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
name: Box<FHIRString>The name of the access policy.
description: Option<Box<FHIRString>>Description of the access policy.
engine: Box<AccessPolicyv2Engine>The type of evaluation that is performed to determine if access is granted or denied.
attribute: Option<Vec<AccessPolicyV2Attribute>>Attributes to use for the policy evaluation.
rule: Option<Vec<AccessPolicyV2Rule>>The rules that govern how the access policy is applied.
target: Option<Vec<AccessPolicyV2Target>>Who the access policy applies to.