pub struct Bundle {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub implicitRules: Option<Box<FHIRUri>>,
pub language: Option<Box<FHIRCode>>,
pub identifier_: Option<Box<Identifier>>,
pub type_: Box<BundleType>,
pub timestamp: Option<Box<FHIRInstant>>,
pub total: Option<Box<FHIRUnsignedInt>>,
pub link: Option<Vec<BundleLink>>,
pub entry: Option<Vec<BundleEntry>>,
pub signature: Option<Box<Signature>>,
}Expand description
A container for a collection of resources.
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
implicitRules: Option<Box<FHIRUri>>A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
language: Option<Box<FHIRCode>>The base language in which the resource is written.
identifier_: Option<Box<Identifier>>A persistent identifier for the bundle that won’t change as a bundle is copied from server to server.
type_: Box<BundleType>Indicates the purpose of this bundle - how it is intended to be used.
timestamp: Option<Box<FHIRInstant>>The date/time that the bundle was assembled - i.e. when the resources were placed in the bundle.
total: Option<Box<FHIRUnsignedInt>>If a set of search matches, this is the total number of entries of type ‘match’ across all pages in the search. It does not include search.mode = ‘include’ or ‘outcome’ entries and it does not provide a count of the number of entries in the Bundle.
link: Option<Vec<BundleLink>>A series of links that provide context to this bundle.
entry: Option<Vec<BundleEntry>>An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).
signature: Option<Box<Signature>>Digital Signature - base64 encoded. XML-DSig or a JWT.