pub struct ClientApplication {Show 14 fields
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub name: Box<FHIRString>,
pub description: Option<Box<FHIRString>>,
pub grantType: Vec<Box<ClientapplicationGrantType>>,
pub responseTypes: Box<ClientapplicationResponseTypes>,
pub secret: Option<Box<FHIRString>>,
pub redirectUri: Option<Vec<Box<FHIRString>>>,
pub uri: Option<Box<FHIRUri>>,
pub logoUri: Option<Box<FHIRUri>>,
pub scope: Option<Box<FHIRString>>,
pub contact: Option<Box<ContactPoint>>,
pub tosUri: Option<Box<FHIRUri>>,
pub policyUri: Option<Box<FHIRUri>>,
}Expand description
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
name: Box<FHIRString>description: Option<Box<FHIRString>>grantType: Vec<Box<ClientapplicationGrantType>>The grant type for this client application.
responseTypes: Box<ClientapplicationResponseTypes>secret: Option<Box<FHIRString>>For client credentials (or other confidential authentication methods), the client secret.
redirectUri: Option<Vec<Box<FHIRString>>>Array of redirection URI strings for use in redirect-based flows such as the authorization code and implicit flows. As required by Section 2 of OAuth 2.0 [RFC6749], clients using flows with redirection MUST register their redirection URI values. Authorization servers that support dynamic registration for redirect-based flows MUST implement support for this metadata value.
uri: Option<Box<FHIRUri>>logoUri: Option<Box<FHIRUri>>scope: Option<Box<FHIRString>>contact: Option<Box<ContactPoint>>tosUri: Option<Box<FHIRUri>>policyUri: Option<Box<FHIRUri>>Trait Implementations
Sourceimpl Clone for ClientApplication
impl Clone for ClientApplication
Sourcefn clone(&self) -> ClientApplication
fn clone(&self) -> ClientApplication
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ClientApplication
impl Debug for ClientApplication
Sourceimpl Default for ClientApplication
impl Default for ClientApplication
Sourcefn default() -> ClientApplication
fn default() -> ClientApplication
Sourceimpl FHIRJSONDeserializer for ClientApplication
impl FHIRJSONDeserializer for ClientApplication
Sourceimpl FHIRJSONSerializer for ClientApplication
impl FHIRJSONSerializer for ClientApplication
fn serialize_value( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_extension( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_field( &self, field: &str, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn is_fp_primitive(&self) -> bool
Sourceimpl MetaValue for ClientApplication
impl MetaValue for ClientApplication
fn fields(&self) -> Vec<&'static str>
fn get_field<'a>(&'a self, field: &str) -> Option<&'a dyn MetaValue>
fn get_field_mut<'a>(&'a mut self, field: &str) -> Option<&'a mut dyn MetaValue>
fn get_index_mut<'a>( &'a mut self, index: usize, ) -> Option<&'a mut dyn MetaValue>
fn get_index<'a>(&'a self, _index: usize) -> Option<&'a dyn MetaValue>
fn typename(&self) -> &'static str
fn as_any(&self) -> &dyn Any
fn flatten(&self) -> Vec<&dyn MetaValue>