pub struct IdentityProvider {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub name: Box<FHIRString>,
pub status: Box<IdentityProviderStatus>,
pub accessType: Box<IdentityProviderAccessType>,
pub oidc: Option<IdentityProviderOidc>,
}Expand description
External identity provider configuration.
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
name: Box<FHIRString>The name of the external identity provider.
status: Box<IdentityProviderStatus>The status of the identity provider.
accessType: Box<IdentityProviderAccessType>Method for connecting to external identity provider.
oidc: Option<IdentityProviderOidc>OIDC connection configuration for the identity provider.