pub struct Membership {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub link: Option<Box<Reference>>,
pub user: Box<Reference>,
}Expand description
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
link: Option<Box<Reference>>user: Box<Reference>Trait Implementations
Sourceimpl Clone for Membership
impl Clone for Membership
Sourcefn clone(&self) -> Membership
fn clone(&self) -> Membership
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Membership
impl Debug for Membership
Sourceimpl Default for Membership
impl Default for Membership
Sourcefn default() -> Membership
fn default() -> Membership
Returns the “default value” for a type. Read more
Sourceimpl FHIRJSONDeserializer for Membership
impl FHIRJSONDeserializer for Membership
Sourceimpl FHIRJSONSerializer for Membership
impl FHIRJSONSerializer for Membership
fn serialize_value( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_extension( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_field( &self, field: &str, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn is_fp_primitive(&self) -> bool
Sourceimpl MetaValue for Membership
impl MetaValue for Membership
fn fields(&self) -> Vec<&'static str>
fn get_field<'a>(&'a self, field: &str) -> Option<&'a dyn MetaValue>
fn get_field_mut<'a>(&'a mut self, field: &str) -> Option<&'a mut dyn MetaValue>
fn get_index_mut<'a>( &'a mut self, index: usize, ) -> Option<&'a mut dyn MetaValue>
fn get_index<'a>(&'a self, _index: usize) -> Option<&'a dyn MetaValue>
fn typename(&self) -> &'static str
fn as_any(&self) -> &dyn Any
fn flatten(&self) -> Vec<&dyn MetaValue>