pub struct Parameters {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub implicitRules: Option<Box<FHIRUri>>,
pub language: Option<Box<FHIRCode>>,
pub parameter: Option<Vec<ParametersParameter>>,
}Expand description
This resource is a non-persisted resource used to pass information into and back from an operation. It has no other use, and there is no RESTful endpoint associated with it.
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
implicitRules: Option<Box<FHIRUri>>A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
language: Option<Box<FHIRCode>>The base language in which the resource is written.
parameter: Option<Vec<ParametersParameter>>A parameter passed to or received from the operation.