pub struct Project {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub name: Box<FHIRString>,
pub fhirVersion: Box<SupportedFhirVersion>,
pub identityProvider: Option<Vec<Box<Reference>>>,
}Expand description
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
name: Box<FHIRString>fhirVersion: Box<SupportedFhirVersion>identityProvider: Option<Vec<Box<Reference>>>Implementations