pub struct User {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub email: Option<Box<FHIRString>>,
pub emailVerified: Option<Box<FHIRBoolean>>,
pub name: Option<Box<HumanName>>,
pub role: Box<UserRole>,
pub federated: Option<Box<Reference>>,
}Expand description
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
email: Option<Box<FHIRString>>emailVerified: Option<Box<FHIRBoolean>>name: Option<Box<HumanName>>role: Box<UserRole>federated: Option<Box<Reference>>Trait Implementations
Sourceimpl FHIRJSONSerializer for User
impl FHIRJSONSerializer for User
fn serialize_value( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_extension( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_field( &self, field: &str, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn is_fp_primitive(&self) -> bool
Sourceimpl MetaValue for User
impl MetaValue for User
fn fields(&self) -> Vec<&'static str>
fn get_field<'a>(&'a self, field: &str) -> Option<&'a dyn MetaValue>
fn get_field_mut<'a>(&'a mut self, field: &str) -> Option<&'a mut dyn MetaValue>
fn get_index_mut<'a>( &'a mut self, index: usize, ) -> Option<&'a mut dyn MetaValue>
fn get_index<'a>(&'a self, _index: usize) -> Option<&'a dyn MetaValue>
fn typename(&self) -> &'static str
fn as_any(&self) -> &dyn Any
fn flatten(&self) -> Vec<&dyn MetaValue>