pub struct ViewDefinition {Show 31 fields
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub implicitRules: Option<Box<FHIRUri>>,
pub language: Option<Box<FHIRCode>>,
pub text: Option<Box<Narrative>>,
pub contained: Option<Vec<Resource>>,
pub extension: Option<Vec<Extension>>,
pub modifierExtension: Option<Vec<Extension>>,
pub url: Option<Box<FHIRUri>>,
pub identifier_: Option<Vec<Identifier>>,
pub version: Option<Box<FHIRString>>,
pub versionAlgorithm: Option<ViewDefinitionVersionAlgorithmTypeChoice>,
pub name: Option<Box<FHIRString>>,
pub title: Option<Box<FHIRString>>,
pub status: BoundCode<PublicationStatus>,
pub experimental: Option<Box<FHIRBoolean>>,
pub date: Option<Box<FHIRDateTime>>,
pub publisher: Option<Box<FHIRString>>,
pub contact: Option<Vec<ContactDetail>>,
pub description: Option<Box<FHIRMarkdown>>,
pub useContext: Option<Vec<UsageContext>>,
pub jurisdiction: Option<Vec<CodeableConcept>>,
pub purpose: Option<Box<FHIRMarkdown>>,
pub copyright: Option<Box<FHIRMarkdown>>,
pub copyrightLabel: Option<Box<FHIRString>>,
pub resource: BoundCode<ResourceTypes>,
pub profile: Option<Vec<FHIRCanonical>>,
pub fhirVersion: Option<Vec<BoundCode<FHIRVersion>>>,
pub constant: Option<Vec<ViewDefinitionConstant>>,
pub select: Vec<ViewDefinitionSelect>,
pub where_: Option<Vec<ViewDefinitionWhere>>,
}Expand description
A ViewDefinition represents a tabular projection of a FHIR resource, where the columns and inclusion criteria are defined by FHIRPath expressions.
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
implicitRules: Option<Box<FHIRUri>>A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
language: Option<Box<FHIRCode>>The base language in which the resource is written.
text: Option<Box<Narrative>>A human-readable narrative that contains a summary of the resource and can be used to represent the content of the resource to a human. The narrative need not encode all the structured data, but is required to contain sufficient detail to make it “clinically safe” for a human to just read the narrative. Resource definitions may define what content should be represented in the narrative to ensure clinical safety.
contained: Option<Vec<Resource>>These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, nor can they have their own independent transaction scope. This is allowed to be a Parameters resource if and only if it is referenced by a resource that provides context/meaning.
extension: Option<Vec<Extension>>May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifierExtension: Option<Vec<Extension>>May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
url: Option<Box<FHIRUri>>An absolute URI that is used to identify this {{title}} when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which an authoritative instance of this {{title}} is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the {{title}} is stored on different servers.
identifier_: Option<Vec<Identifier>>A formal identifier that is used to identify this {{title}} when it is represented in other formats, or referenced in a specification, model, design or an instance.
version: Option<Box<FHIRString>>The identifier that is used to identify this version of the {{title}} when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the {{title}} author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence without additional knowledge. (See the versionAlgorithm element.)
versionAlgorithm: Option<ViewDefinitionVersionAlgorithmTypeChoice>Indicates the mechanism used to compare versions to determine which is more current.
name: Option<Box<FHIRString>>A natural language name identifying the {{title}}. This name should be usable as an identifier for the resource by machine processing applications such as code generation.
title: Option<Box<FHIRString>>A short, descriptive, user-friendly title for the {{title}}.
status: BoundCode<PublicationStatus>The current state of this {{title}}.
experimental: Option<Box<FHIRBoolean>>A Boolean value to indicate that this {{title}} is authored for testing purposes (or education/evaluation/marketing) and is not intended for genuine usage.
date: Option<Box<FHIRDateTime>>The date (and optionally time) when the {{title}} was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the {{title}} changes.
publisher: Option<Box<FHIRString>>The name of the organization or individual responsible for the release and ongoing maintenance of the {{title}}.
contact: Option<Vec<ContactDetail>>Contact details to assist a user in finding and communicating with the publisher.
description: Option<Box<FHIRMarkdown>>A free text natural language description of the {{title}} from a consumer’s perspective.
useContext: Option<Vec<UsageContext>>The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, …) or may be references to specific programs (insurance plans, studies, …) and may be used to assist with indexing and searching for appropriate {{title}}s.
jurisdiction: Option<Vec<CodeableConcept>>A legal or geographic region in which the {{title}} is intended to be used.
purpose: Option<Box<FHIRMarkdown>>Explanation of why this {{title}} is needed and why it has been designed as it has.
copyright: Option<Box<FHIRMarkdown>>A copyright statement relating to the {{title}} and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the {{title}}.
copyrightLabel: Option<Box<FHIRString>>A short string (<50 characters), suitable for inclusion in a page footer that identifies the copyright holder, effective period, and optionally whether rights are resctricted. (e.g. ‘All rights reserved’, ‘Some rights reserved’).
resource: BoundCode<ResourceTypes>The FHIR resource that the view is based upon, e.g. ‘Patient’ or ‘Observation’.
profile: Option<Vec<FHIRCanonical>>Indicates that this definition was intended to create a view over a set of resources conforming to the specified FHIR profiles. Each of these profiles SHALL be based upon the resource type specified in resource.
fhirVersion: Option<Vec<BoundCode<FHIRVersion>>>The FHIR version(s) for the FHIR resource. The value of this element is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor].
constant: Option<Vec<ViewDefinitionConstant>>A constant is a value that is injected into a FHIRPath expression through the use of a FHIRPath external constant with the same name.
select: Vec<ViewDefinitionSelect>The select structure defines the columns to be used in the resulting view. These are expressed
in the column structure below, or in nested selects for nested resources.
where_: Option<Vec<ViewDefinitionWhere>>A series of zero or more FHIRPath constraints to filter resources for the view. Every constraint must evaluate to true for the resource to be included in the view.
Implementations