pub struct ViewDefinitionConstant {
pub id: Option<String>,
pub extension: Option<Vec<Extension>>,
pub modifierExtension: Option<Vec<Extension>>,
pub name: Box<FHIRString>,
pub value: ViewDefinitionConstantValueTypeChoice,
}Expand description
A constant is a value that is injected into a FHIRPath expression through the use of a FHIRPath external constant with the same name.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Extension>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifierExtension: Option<Vec<Extension>>May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
name: Box<FHIRString>Name of constant (referred to in FHIRPath as %[name])
value: ViewDefinitionConstantValueTypeChoiceThe value that will be substituted in place of the constant reference. This
is done by including %your_constant_name in a FHIRPath expression, which effectively converts
the FHIR literal defined here to a FHIRPath literal used in the path expression.
Support for additional types may be added in the future.
Implementations