pub struct Project {
pub id: Option<String>,
pub meta: Option<Box<Meta>>,
pub name: Box<FHIRString>,
pub fhirVersion: Box<SupportedFhirVersion>,
pub identityProvider: Option<Vec<Box<Reference>>>,
}Expand description
Fields
id: Option<String>The logical id of the resource, as used in the URL for the resource. Once assigned, this value never changes.
meta: Option<Box<Meta>>The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
name: Box<FHIRString>fhirVersion: Box<SupportedFhirVersion>identityProvider: Option<Vec<Box<Reference>>>Trait Implementations
Sourceimpl FHIRJSONSerializer for Project
impl FHIRJSONSerializer for Project
fn serialize_value( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_extension( &self, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn serialize_field( &self, field: &str, writer: &mut dyn Write, ) -> Result<bool, SerializeError>
fn is_fp_primitive(&self) -> bool
Sourceimpl MetaValue for Project
impl MetaValue for Project
fn fields(&self) -> Vec<&'static str>
fn get_field<'a>(&'a self, field: &str) -> Option<&'a dyn MetaValue>
fn get_field_mut<'a>(&'a mut self, field: &str) -> Option<&'a mut dyn MetaValue>
fn get_index_mut<'a>( &'a mut self, index: usize, ) -> Option<&'a mut dyn MetaValue>
fn get_index<'a>(&'a self, _index: usize) -> Option<&'a dyn MetaValue>
fn typename(&self) -> &'static str
fn as_any(&self) -> &dyn Any
fn flatten(&self) -> Vec<&dyn MetaValue>